#!/bin/ksh
#\
exec tixwish "$0" "$@"
set months { "" Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec }

proc save_todo {w m} {
global ty mm dd yy months todolist
set text "[$w.f1.e get]"
if {[string trim $text]=={}} {
	tk_messageBox -icon error -type ok -title "Error" \
		-message "Empty Entry!"
	return
}
set ty [expr {$ty=="task"?"task":"call"}]
if {$dd=="never" || $mm=="never" || $yy=="never"} {
	lappend todolist "todo 0.0.0 $ty 0 \"$text\""
} else {
	for {set i 1} {$i<=12} {incr i} {if {$mm==[lindex $months $i]} break}
	lappend todolist "todo $yy.$i.$dd $ty 0 \"$text\""
}
destroy $m.f1.f.lb
fill_todo $m
}

proc add_todo {master} {
global labelbgcolor labelfgcolor labelfont
global entrybgcolor entryfgcolor entryfont
global buttonbgcolor buttonfgcolor buttonfont
global months
global ty mm dd yy
set ty task
set time [clock seconds]
set dd [clock format $time -format %d]
set mm [clock format $time -format %b]
set yy [clock format $time -format %Y]
set w .add_todo
toplevel $w
wm title $w "Add to Todo List"
wm iconname $w "Add to Todo List"

frame $w.f1 -bg $labelbgcolor
frame $w.f2 -bg $labelbgcolor
frame $w.f3 -bg $labelbgcolor
entry $w.f1.e -wid 40 \
	-bg $entrybgcolor -fg $entryfgcolor -font $entryfont -re groove -bd 2

set m [tk_optionMenu $w.f2.m mm {never}]
$m configure -fg $labelfgcolor -bg $labelbgcolor -font $labelfont
$w.f2.m configure -fg $labelfgcolor -bg $labelbgcolor -font $labelfont \
	-relief flat -bd 0 -activeback $labelbgcolor -padx 0 -pady 2 \
	-highlightthickness 0
for {set i 1} {$i<=12} {incr i} {
	$m add radiobutton -variable mm -label [lindex $months $i]
}

set m [tk_optionMenu $w.f2.d dd {never}]
$m configure -fg $labelfgcolor -bg $labelbgcolor -font $labelfont
$w.f2.d configure -fg $labelfgcolor -bg $labelbgcolor -font $labelfont \
	-relief flat -bd 0 -activeback $labelbgcolor -padx 0 -pady 2 \
	-highlightthickness 0
for {set i 1} {$i<=31} {incr i} {
	$m add radiobutton -variable dd -label $i
}

set m [tk_optionMenu $w.f2.y yy {never}]
$m configure -fg $labelfgcolor -bg $labelbgcolor -font $labelfont -bd 0
$w.f2.y configure -fg $labelfgcolor -bg $labelbgcolor -font $labelfont \
	-relief flat -bd 0 -activeback $labelbgcolor -padx 0 -pady 2 \
	-highlightthickness 0
for {set i 1998} {$i<=2005} {incr i} {
	$m add radiobutton -variable yy -label $i
}

frame $w.f2.f -bd 1 -relief raised

radiobutton $w.f2.r1 -text Call -var ty -val call \
	-font $labelfont -bg $labelbgcolor -fg $labelfgcolor \
	-highlightthickness 0 -activebackground $labelbgcolor
radiobutton $w.f2.r2 -text Task -var ty -val task \
	-font $labelfont -bg $labelbgcolor -fg $labelfgcolor \
	-highlightthickness 0 -activebackground $labelbgcolor

button $w.f3.c -text "Done" -command "grab $master; destroy $w" -bd 1 \
	-font $labelfont -bg $labelbgcolor -fg $labelfgcolor
button $w.f3.s -text "Save" -command "save_todo {$w} {$master}" -bd 1 \
	-font $labelfont -bg $labelbgcolor -fg $labelfgcolor

pack $w.f1.e -fill x -expand yes

pack $w.f2.d -side left -fill both -expand yes
pack $w.f2.m -side left -fill both -expand yes
pack $w.f2.y -side left -fill both -expand yes
pack $w.f2.f -side left -expand no -fill y
pack $w.f2.r1 -side left -fill both -expand yes
pack $w.f2.r2 -side left -fill both -expand yes

pack $w.f3.s -side left  -fill both -expand yes -pady 2
pack $w.f3.c -side right -fill both -expand yes -pady 2

pack $w.f1 -fill both -expand yes
pack $w.f2 -fill x -expand yes
pack $w.f3 -fill x -expand yes
focus $w.f1.e
grab $w

}
proc del_todo {w} {
global todolist
set i [$w.f1.f.lb curselection]
if {$i=={}} {
	tk_messageBox -icon error -type ok -title "Error" \
		-message "No Selection"
	return
}
if {[tk_messageBox -icon question -type yesno -title "Are You Sure ?" \
	-message "Are You Sure"]=="no"} {
	return
}
destroy $w.f1.f.lb
set todolist [lreplace $todolist $i $i]
fill_todo $w
}

proc fill_todo {w} {
global todolist
global labelbgcolor labelfgcolor labelfont

listbox $w.f1.f.lb -font $labelfont -selectmode single
pack $w.f1.f.lb -padx 5 -pady 5 -expand yes -fill both
bind $w.f1.f.lb <ButtonRelease> "show_todo {$w}"

if [info exists todolist] {
	for {set i 0} {$i<[llength $todolist]} {incr i} {
		set tdl [lindex $todolist $i]
		$w.f1.f.lb insert end [lindex $tdl 4]
	}
}
$w.f2.f.ld config -text "Date" -justify center
$w.f2.f.ls config -text "Status" -justify center
}

proc show_todo {win} {
global todolist ttype months
set w $win.f1.f.lb
set i [$w curselection]
if {$i=={}} return
set sel [lindex $todolist $i]
set dt [split [lindex $sel 1] .]
set st [lindex $sel 3]

set yy [lindex $dt 0]
set mm [lindex $months [lindex $dt 1]]
set dd [lindex $dt 2]

set ttype [expr {[lindex $sel 2]=="task" ? "task" : "call" }]

$win.f2.f.ld config -text [expr {!$dd && !$yy ? "No Due Date" : "$dd $mm $yy" }]

$win.f2.f.ls config -text [expr {!$st ? "pending" : "completed" }]

}

proc _todo {w} {
global labelbgcolor labelfgcolor labelfont
global entrybgcolor entryfgcolor entryfont
global buttonbgcolor buttonfgcolor buttonfont
global ttype

if [winfo exists $w] return
toplevel $w
wm title $w "Todo Editor"
wm iconname $w "Todo Editor"
grab $w

_frame $w.f1 -wid 300 -he 150
_frame $w.f2 -wid 120 -he 150
_frame $w.f3 -bd 2 -re ridge

label $w.f2.f.ld \
	-bg $entrybgcolor -fg $entryfgcolor -font $labelfont -re groove -bd 2
label $w.f2.f.ls \
	-bg $entrybgcolor -fg $entryfgcolor -font $labelfont -re groove -bd 2

radiobutton $w.f2.f.r1 -text Call -var ttype -val call \
	-font $labelfont -bg $labelbgcolor -fg $labelfgcolor \
	-highlightthickness 0 -activebackground $labelbgcolor
radiobutton $w.f2.f.r2 -text Task -var ttype -val task \
	-font $labelfont -bg $labelbgcolor -fg $labelfgcolor \
	-highlightthickness 0 -activebackground $labelbgcolor

button $w.f2.f.a -text Add... -bd 1 -command "add_todo {$w}" \
	-font $buttonfont -bg $buttonbgcolor -fg $buttonfgcolor
button $w.f2.f.d -text Delete -bd 1 -command "del_todo {$w}" \
	-font $buttonfont -bg $buttonbgcolor -fg $buttonfgcolor

pack $w.f2.f.ld -ipadx 5 -ipady 5 -pady 2 -padx 2 -fill x
pack $w.f2.f.ls -ipadx 5 -ipady 5 -pady 2 -padx 2 -fill x
pack $w.f2.f.d -side bottom -fill x
pack $w.f2.f.a -side bottom -fill x
pack $w.f2.f.r1 $w.f2.f.r2 -side left -fill x

fill_todo $w

button $w.f3.d -text Dismiss -command "destroy $w" -bd 1\
	 -bg $buttonbgcolor -fg $buttonfgcolor -font $buttonfont
pack $w.f3.d -expand yes -fill x 

pack $w.f3 -side bottom -fill x 
pack $w.f1 -side left -fill both -expand yes
pack $w.f2 -fill both -expand yes
}
